@@ -20,6 +20,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 /* lcd.c   by Paul Wilkins 3/22/97 */
 
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
@@ -677,7 +679,7 @@ void convertSelection(
 #else
       switch(selection->target){
 #endif
-         case GDK_TARGET_STRING:
+/*         case GDK_TARGET_STRING: */
          case TARGET_STRING:
 	    gtk_selection_data_set(
 	       selection,
